``boxplot`` tick labels
^^^^^^^^^^^^^^^^^^^^^^^

The parameter *labels* has been removed in favour of *tick_labels* for clarity and
consistency with `~.Axes.bar`.

Image path semantics of toolmanager-based tools
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

Previously, MEP22 ("toolmanager-based") Tools would try to load their icon
(``tool.image``) relative to the current working directory, or, as a fallback, from
Matplotlib's own image directory. Because both approaches are problematic for
third-party tools (the end-user may change the current working directory at any time,
and third-parties cannot add new icons in Matplotlib's image directory), this behavior
has been removed; instead, ``tool.image`` is now interpreted relative to the directory
containing the source file where the ``Tool.image`` class attribute is defined.
(Defining ``tool.image`` as an absolute path also works and is compatible with both the
old and the new semantics.)
